@@ -21,7 +21,8 @@ fn script_options_new() {
     let options = ScriptOptions::new();
 
     assert!(options.runner.is_none());
-    assert!(options.capture_output);
+    assert_eq!(options.input_redirection, IoOptions::Inherit);
+    assert_eq!(options.output_redirection, IoOptions::Pipe);
     assert!(!options.exit_on_error);
     assert!(!options.print_commands);
 }
